@@ -66,8 +66,9 @@ def test_get_tiddlers_from_bag():
     assert len(tiddlers) ==  10, 'there are 10 tiddlers in bag0'
     text = ''
     for tiddler in tiddlers:
+        store.get(tiddler)
         text += tiddler.text
-    assert 'i am tiddler 4' in text, 'we got some of the right text'
+    assert 'i am tiddler 4' in text
 
 def test_filter_tiddlers_from_bag():
     """
@@ -76,6 +77,6 @@ def test_filter_tiddlers_from_bag():
     bag = Bag('bag0')
     bag = store.get(bag)
 
-    tiddlers = list(control.filter_tiddlers_from_bag(bag, 'select=tag:tagfour'))
+    tiddlers = list(control._filter_tiddlers_from_bag(bag, 'select=tag:tagfour',
+        environ={'tiddlyweb.store': store}))
     assert len(tiddlers) == 3
-
